@@ -7,7 +7,7 @@ use HTTP::Cookies();
 use HTTP::Headers();
 use Carp();
 use English qw(-no_match_vars);
-our $VERSION = '0.9991';
+our $VERSION = '0.9992';
 
 our @CARP_NOT = ('Net::DNS::DynDNS');
 sub DEFAULT_TIMEOUT                      { return 60 }
@@ -53,6 +53,7 @@ sub new {
     }
     my $ua = LWP::UserAgent->new( timeout => $timeout )
       ; # no sense in using keep_alive => 1 because updates and checks are supposed to happen infrequently
+    $ua->env_proxy();
     $ua->agent($name);
     my $cookie_jar = HTTP::Cookies->new( hide_cookie2 => 1 );
     $ua->cookie_jar($cookie_jar);
@@ -201,7 +202,7 @@ sub _validate_update {
     }
     if (
         not( $hostnames =~
-            /^(?:(?:[\p{IsAlphabetic}\-]+[.])+[\p{IsAlphabetic}\-]+,?)+$/xsm )
+            /^(?:(?:[[:alpha:]\d\-]+[.])+[[:alpha:]\d\-]+,?)+$/xsm )
       )
     {
         Carp::croak(
@@ -293,8 +294,7 @@ sub _check_mx {
         if ( ( defined $params->{mx} ) && ( $params->{mx} ) ) {
             if (
                 not( $params->{mx} =~
-/^(?:(?:[\p{IsAlphabetic}\-]+[.])+[\p{IsAlphabetic}\-]+,?)+$/xsm
-                )
+                    /^(?:(?:[[:alpha:]\d\-]+[.])+[[:alpha:]\d\-]+,?)+$/xsm )
               )
             {
                 Carp::croak(
@@ -498,3 +498,116 @@ sub _parse_content {
 }
 
 1;
+
+__END__
+=head1 NAME
+
+Net::DNS::DynDNS - Update dyndns.org with correct ip address for your domain name
+
+=head1 VERSION
+ 
+Version 0.9992
+
+=head1 SYNOPSIS
+
+  print Net::DNS::DynDNS->default_ip_address();
+  print Net::DNS::DynDNS->new('user', 'password')->update('test.dyndns.org,test.homeip.net');
+
+=head1 DESCRIPTION
+
+This module allows automated updates to your dyndns.org domain name to your
+current ip address.  This is useful for people running servers that operate 
+off dynamic ip addresses.  
+
+=head1 SUBROUTINES/METHODS
+
+=item default_ip_address
+
+returns your current ip address according to dyndns.org.  This function should
+not be used more than once every 10 minutes according to terms of usage for
+dyndns.org.
+
+=item new( $username, $password, $params )
+
+returns a new object for updating dyndns.org entries.  The username and password
+parameters are from your dyndns.org account.
+
+   Parameter            Default
+   server               dyndns.org
+   dns_server           members.dyndns.org
+   check_ip             checkip.dyndns.org
+
+=item update_allowed ( $setting )
+
+returns whether the object is permitted to make another update to dyndns.org without 
+human intervention.  There are a list of return codes at 
+http://www.dyndns.org/developers/specs/return.html that require this behaviour.  To
+signal that human intervention has allowed updating to continue, pass a true value 
+in the parameter list.
+
+=item update( $hostnames, $ip_address, $params )
+
+returns the ip address that has been assigned to the hostnames.  The hostnames should be
+fully qualified domain names.  If there is more than one hostname to be updated, they should
+be separated with a comma.  The ip_address argument is optional.  It specifies which ip 
+address should be assigned to the hostnames argument.  If the ip_address argument is not 
+supplied, dyndns.org will assign your current ip address to the hostnames.  The optional
+params argument is a hashref that may contain the following values
+
+   Parameter            Default   Values
+   wildcard             none      ON | OFF | NOCHG 
+   mx                   none      any valid fully qualified hostname 
+   backmx               none      YES | NO
+   offline              none      YES | NO
+   protocol             https     http | https
+
+Further information about each of these parameters is available at
+http://www.dyndns.org/developers/specs/syntax.html
+
+=head1 CONFIGURATION AND ENVIRONMENT
+ 
+Net::DNS::DynDNS requires no configuration files or environment variables.  It will use the http_* Environment Variables to determine a proxy server
+
+=head1 DEPENDENCIES
+ 
+Net::DNS::DynDNS requires the following non-core Perl modules
+ 
+=over
+ 
+=item *
+L<LWP|LWP>
+ 
+=item *
+L<Net::HTTPS|Net::HTTPS>
+ 
+=item *
+L<HTTP::Cookies|HTTP::Cookies>
+ 
+=item *
+L<HTTP::Headers|HTTP::Headers>
+
+=head1 INCOMPATIBILITIES
+ 
+None reported
+
+=head1 AUTHOR
+
+David Dick <ddick@cpan.org>
+
+=head1 BUGS AND LIMITATIONS
+
+None known at this point.
+
+Interested in receiving patches to make this compatible with other DDNS providers
+ 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+ 
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+ 
+See http://dev.perl.org/licenses/ for more information.
+
+=cut
